# Lib
Here are the libraries that is make up most of the broker's logic. 

Worth mentioning are:

`features` are tests, OF use BDD.
`messaging` are the server-side implementations of the OF websocket implementation
`schema_mongodb` adds MongoDB specific features to the jsonschema library 